@@ -2,17 +2,21 @@
 Will use special scheduler running on rank 0 to orchestrate
 the needed behavior """
 
+import warnings
 from functools import partial
 from threading import Thread
-from typing import Any, Callable, Generator, List
+from typing import Any, Callable, Generator, List, cast
 
 import dill
+import numpy as np
 from mpi4py import MPI
 from numpy import iterable
 from pydash import flatten
 
 from blazer.logs import logging
 
+warnings.filterwarnings("ignore", category=np.VisibleDeprecationWarning)
+
 comm = MPI.COMM_WORLD
 rank = comm.Get_rank()
 size = comm.Get_size()
@@ -141,6 +145,39 @@ if rank != 0:
     thread.start()
 
 
+def fetch(data: List, stream=False):
+    """Given a sharded data set, retrieve it from the ranks"""
+    data = cast(List, comm.gather(data, root=0))
+    if rank == 0:
+        if not stream:
+            _data = flatten([list(d) for d in data])
+            return _data
+        else:
+
+            def fetchstream(data) -> Generator:
+                for d in data:
+                    yield list(d)
+
+            return fetchstream(data)
+    else:
+        return []
+
+
+def shard(data: List):
+    """Take a data set and spread it across the ranks"""
+    import numpy as np
+
+    if rank == 0:
+        data = list(np.array(data, dtype=object))
+        _chunks = np.array_split(data, size)
+    else:
+        _chunks = None
+
+    data = comm.scatter(_chunks, root=0)
+
+    return data
+
+
 def parallel(defers: List, *args):
     """Run list of tasks in parallel across compute fabric"""
     logging.debug("[%s] parallel rank %s %s", host, rank, args)
